@@ -1,7 +1,7 @@
 package Bencher::Scenario::SetComparison;
 
-our $DATE = '2016-10-19'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -42,7 +42,7 @@ Bencher::Scenario::SetComparison - Benchmark set comparison
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::SetComparison (from Perl distribution Bencher-Scenario-SetComparison), released on 2016-10-19.
+This document describes version 0.003 of Bencher::Scenario::SetComparison (from Perl distribution Bencher-Scenario-SetComparison), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -108,7 +108,7 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m SetComparison >>):
 
@@ -116,25 +116,28 @@ Benchmark with default options (C<< bencher -m SetComparison >>):
  +-------------+--------------+-----------+-----------+------------+-----------+---------+
  | participant | dataset      | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
  +-------------+--------------+-----------+-----------+------------+-----------+---------+
- | Test::Deep  | elems=200num |      4.18 |  239      |          1 |   0.00021 |      20 |
- | Test::Deep  | elems=100num |     17    |   60      |          4 | 6.3e-05   |      20 |
- | Test::Deep  | elems=10num  |   1500    |    0.67   |        360 | 9.6e-07   |      20 |
- | Set::Tiny   | elems=200num |  15000    |    0.067  |       3600 | 1.1e-07   |      20 |
- | Set::Tiny   | elems=100num |  30000    |    0.033  |       7200 | 6.2e-08   |      23 |
- | Set::Tiny   | elems=10num  | 190000    |    0.0054 |      45000 | 6.7e-09   |      20 |
+ | Test::Deep  | elems=200num |       5.4 | 180       |          1 |   0.00053 |      20 |
+ | Test::Deep  | elems=100num |      22   |  46       |          4 |   0.00031 |      20 |
+ | Test::Deep  | elems=10num  |    1900   |   0.53    |        350 | 6.2e-07   |      21 |
+ | Set::Tiny   | elems=200num |   17000   |   0.059   |       3100 | 5.6e-07   |      20 |
+ | Set::Tiny   | elems=100num |   30000   |   0.03    |       6000 | 3.6e-07   |      25 |
+ | Set::Tiny   | elems=10num  |  239000   |   0.00419 |      44100 | 1.7e-09   |      20 |
  +-------------+--------------+-----------+-----------+------------+-----------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m SetComparison --module-startup >>):
 
  #table2#
- +---------------------+-----------+------------------------+------------+-----------+---------+
- | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
- +---------------------+-----------+------------------------+------------+-----------+---------+
- | Test::Deep          |      26   |                   20   |        1   |   0.00018 |      21 |
- | Set::Tiny           |       6.4 |                    0.4 |        4.1 | 2.1e-05   |      20 |
- | perl -e1 (baseline) |       6   |                    0   |        5   | 6.6e-05   |      20 |
- +---------------------+-----------+------------------------+------------+-----------+---------+
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
+ | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
+ | Test::Deep          | 1                            | 4.4                | 16             |      41   |                   36.1 |        1   |   0.00014 |      20 |
+ | Set::Tiny           | 0.82                         | 4.1                | 16             |       6.7 |                    1.8 |        6.1 | 2.6e-05   |      20 |
+ | perl -e1 (baseline) | 5.2                          | 8.6                | 24             |       4.9 |                    0   |        8.4 | 1.3e-05   |      20 |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
+
+
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 BENCHMARK NOTES
 
@@ -168,7 +171,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
